package com.jprofiler.api.agent.probe;

/**
 * Describes the type of additional data columns for events and control objects.
 *
 * @see ProbeMetaData#addAdditionalData(String, DataType)
 * @see ProbeMetaData#addAdditionalControlObjectData(String, DataType, boolean)
 */
public class DataType {

    /**
     * The data consists of arbitrary objects. The JProfiler GUI displays them by calling their {@code toString()}
     * methods.
     */
    public static final DataType OBJECT = new DataType("object");

    /**
     * The data consists of strings.
     */
    public static final DataType STRING = new DataType("string");

    /**
     * The data consists of interned strings. In this case, the agent can handle them more efficiently.
     */
    public static final DataType INTERNED_STRING = new DataType("interned string");

    /**
     * The data consists of instances of {@code java.lang.Boolean}.
     */
    public static final DataType BOOLEAN = new DataType("boolean");

    /**
     * The data consists of instances of {@code java.lang.Integer}.
     */
    public static final DataType INT = new DataType("int");

    /**
     * The data consists of instances of {@code java.lang.Long}.
     */
    public static final DataType LONG = new DataType("long");

    /**
     * The data consists of instances of {@code java.lang.Float}.
     */
    public static final DataType FLOAT = new DataType("float");

    /**
     * The data consists of instances of {@code java.lang.Double}.
     */
    public static final DataType DOUBLE = new DataType("double");

    private String name;

    private DataType(String name) {
        this.name = name;
    }

    @Override
    public String toString() {
        return name;
    }
}
